aboutsummaryrefslogtreecommitdiffstats
path: root/ui/gtk/iax2_analysis.c
diff options
context:
space:
mode:
Diffstat (limited to 'ui/gtk/iax2_analysis.c')
-rw-r--r--ui/gtk/iax2_analysis.c12
1 files changed, 5 insertions, 7 deletions
diff --git a/ui/gtk/iax2_analysis.c b/ui/gtk/iax2_analysis.c
index 6f7fe77c73..d132bf35e8 100644
--- a/ui/gtk/iax2_analysis.c
+++ b/ui/gtk/iax2_analysis.c
@@ -3688,7 +3688,6 @@ void iax2_analysis_cb(GtkAction *action _U_, gpointer user_data _U_)
gchar filter_text[256];
dfilter_t *sfcode;
capture_file *cf;
- gboolean frame_matched;
frame_data *fdata;
GList *strinfo_list;
GList *filtered_list = NULL;
@@ -3710,17 +3709,16 @@ void iax2_analysis_cb(GtkAction *action _U_, gpointer user_data _U_)
if (fdata == NULL)
return; /* if we exit here it's an error */
- /* dissect the current frame */
- if (!cf_read_frame(cf, fdata))
- return; /* error reading the frame */
+ /* dissect the current record */
+ if (!cf_read_record(cf, fdata))
+ return; /* error reading the record */
epan_dissect_init(&edt, cf->epan, TRUE, FALSE);
epan_dissect_prime_dfilter(&edt, sfcode);
epan_dissect_run(&edt, &cf->phdr, frame_tvbuff_new_buffer(fdata, &cf->buf),
fdata, NULL);
- /* if it is not an iax2 frame, show an error dialog */
- frame_matched = dfilter_apply_edt(sfcode, &edt);
- if (frame_matched != 1) {
+ /* if it is not an iax2 packet, show an error dialog */
+ if (!dfilter_apply_edt(sfcode, &edt)) {
epan_dissect_cleanup(&edt);
simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK,
"Please select an IAX2 packet.");